@@ -42,7 +42,9 @@
 (defun goby-image-help-echo (win buf pos)
   (unless (eq major-mode 'goby-view-mode)
     (let ((image (get-text-property pos 'display buf)))
-      (nth 1 (member :mewfile image)))))
+      (format "%s (%s)"
+	      (nth 1 (member :mewfile image))
+	      (nth 1 (member :mewtag image))))))
 
 (defun goby-line-over-p (&optional pos)
   (goto-char (or pos (point-min)))
@@ -72,7 +74,7 @@
 	(delete-region beg mid)
       (let ((i 0) j beg1 spaces)
 	(narrow-to-region beg end)
-	;; If the line contains images only (without text), 
+	;; If the line contains images only (without text),
 	;; vertical-motion works wrong. So, use "[" as text,
 	;; and put the space property onto "]".
 	(setq beg1 (1+ beg)) ;; "]"
@@ -135,8 +137,6 @@
      (background-color . ,goby-background-color)
      (cursor-color     . ,goby-cursor-color)
      (mouse-color      . ,goby-pointer-color)))
-  (make-variable-frame-local 'face-font-rescale-alist)
-  (modify-frame-parameters (selected-frame) '((face-font-rescale-alist . nil)))
   (goby-x-window-manager '(1 "_NET_WM_STATE_MAXIMIZED_VERT" 0))
   (run-hooks 'goby-decorate-initial-frame-hook))
 
@@ -163,6 +163,7 @@
      (top  . (+ ,goby-window-manager-view-top-position))
      (left . (+ ,goby-window-manager-view-left-position))
      (height . ,(+ height goby-window-manager-bottom-margin))))
+  (if (fboundp 'ns-toggle-fullscreen) (ns-toggle-fullscreen))
   (goby-x-window-manager '(1 "_NET_WM_STATE_FULLSCREEN" 0))
   (copy-face 'fringe 'goby-old-fringe-face)
   (set-face-attribute
@@ -181,6 +182,7 @@
   (when (boundp 'x-pointer-shape)
     (setq x-pointer-shape goby-old-pointer-shape))
   (setq goby-old-pointer-shape nil)
+  (if (fboundp 'ns-toggle-fullscreen) (ns-toggle-fullscreen))
   (modify-frame-parameters
    (selected-frame)
    `((cursor-type . box)
@@ -217,7 +219,7 @@
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -226,7 +228,7 @@
 ;; 3. Neither the name of the author nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
