@@ -66,6 +66,7 @@
    ("/" . goby-face-math-divide)
    ("i" . goby-insert-image)
    ("s" . goby-change-scale)
+   ("t" . goby-toggle-tag)
    ("c" . goby-center-line)
    ("-" . goby-insert-bar)
    ("*" . goby-insert-item)
@@ -110,6 +111,8 @@
 
 (defvar goby-theme 'light)
 
+(defvar goby-use-italic-for-math t)
+
 ;; to pacify the byte-compiler
 (defmacro goby-def-theme (dark light)
   `(if (eq goby-theme 'dark) ,dark ,light))
@@ -128,7 +131,7 @@
 
 (defvar goby-view-mouse-face-foreground-color
   (goby-def-theme "#ccaa00" "#003355")) ;; 553300
-(defvar goby-view-mouse-face-background-color   
+(defvar goby-view-mouse-face-background-color
   (goby-def-theme "#3355ff" "#ffccaa")) ;;aaccff
 
 (defface goby-view-mouse
@@ -172,9 +175,11 @@
 (defvar goby-bar-string "[-]")
 (defvar goby-item-string "[*]")
 (defvar goby-pause-string "[#]")
-(defvar goby-image-format  "[image \"%s\"]")
-(defvar goby-image-format2 "[image \"%s\" %s]")
-(defvar goby-image-regex "\\[image \"\\([^\"]+\\)\" ?\\([^]]+\\)?\\]")
+(defvar goby-image-format "[image \"%s\" %s<%s>]")
+;; backward compatibility
+(defvar goby-image-regex "\\[image \"\\([^\"]+\\)\" ?\\([^]<> ]+\\)?<?\\([^]<> ]+\\)?>?\\]")
+(defvar goby-image-private "private")
+(defvar goby-image-public  "public")
 
 (defvar goby-image-spec
   '(("\\.pnm$" t)
@@ -303,7 +308,7 @@ Set this to non-nil when you are using KDE or Gnome."
 
 (cond
  ((eq system-type 'darwin)
-  (defvar goby-prog-capture "screencapture") 
+  (defvar goby-prog-capture "screencapture")
   (defvar goby-prog-capture-args 'goby-prog-capture-args-for-darwin))
  (t
   (defvar goby-prog-capture "import")
@@ -327,7 +332,7 @@ Set this to non-nil when you are using KDE or Gnome."
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -336,7 +341,7 @@ Set this to non-nil when you are using KDE or Gnome."
 ;; 3. Neither the name of the author nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
