@@ -19,10 +19,10 @@
 (defvar goby-buffer-end nil)
 (defvar goby-buffer-page-end nil)
 
-(mapcar 'make-variable-buffer-local
-	'(goby-buffer-height
-	  goby-buffer-end
-	  goby-buffer-page-end))
+(mapc 'make-variable-buffer-local
+      '(goby-buffer-height
+	goby-buffer-end
+	goby-buffer-page-end))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -32,21 +32,23 @@
 (defun goby-view-mode (&optional screen-dump)
   "Enter Goby View mode."
   (interactive)
-  (setq goby-buffer-height (frame-parameter (selected-frame) 'height))
-  (setq major-mode 'goby-view-mode)
-  (setq mode-name goby-view-mode-name)
-  (use-local-map goby-view-mode-map)
-  (run-hooks 'goby-view-mode-enter-hook)
-  (goby-decorate-view-frame goby-buffer-height)
-  (run-hooks 'goby-view-mode-enter-hook2)
-  (setq goby-buffer-end (point-max))
-  (forward-page -1)
-  (unless (= (point) 1) (forward-line))
-  (goby-narrow-to-page)
-  (goby-decorate-page screen-dump)
-  (unless screen-dump (goby-first-pause))
-  (setq buffer-read-only t)
-  (message ""))
+  (if (eq major-mode 'goby-view-mode)
+      (message "Already view mode")
+    (setq goby-buffer-height (frame-parameter (selected-frame) 'height))
+    (setq major-mode 'goby-view-mode)
+    (setq mode-name goby-view-mode-name)
+    (use-local-map goby-view-mode-map)
+    (run-hooks 'goby-view-mode-enter-hook)
+    (goby-decorate-view-frame goby-buffer-height)
+    (run-hooks 'goby-view-mode-enter-hook2)
+    (setq goby-buffer-end (point-max))
+    (forward-page -1)
+    (unless (= (point) 1) (forward-line))
+    (goby-narrow-to-page)
+    (goby-decorate-page screen-dump)
+    (unless screen-dump (goby-first-pause))
+    (setq buffer-read-only t)
+    (message "")))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -402,7 +404,7 @@
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -411,7 +413,7 @@
 ;; 3. Neither the name of the author nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
