@@ -2,7 +2,7 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Aug  9, 2003
-;; Revised: Apr 12, 2009
+;; Revised: Jun 29, 2011
 
 ;;; Commentary:
 
@@ -10,7 +10,7 @@
 
 ;;; Code:
 
-(defconst goby-version "1.0")
+(defconst goby-version "1.1")
 
 (require 'goby-vars)
 (require 'goby-emacs)
@@ -49,6 +49,9 @@
 (defvar goby-j-fonts-base 10)
 (defvar goby-m-fonts-base 100)
 
+(defvar goby-math-base
+  (if goby-use-italic-for-math goby-m-fonts-base goby-a-fonts-base))
+
 (defvar goby-a-fonts-lim (+ goby-a-fonts-base (length goby-a-fonts)))
 (defvar goby-j-fonts-lim (+ goby-j-fonts-base (length goby-j-fonts)))
 
@@ -209,8 +212,8 @@ Minor mode for editing large TrueType fonts and images.
 		    (> (prefix-numeric-value arg) 0)))
   (cond
    (goby-mode
-    (make-local-variable 'vertical-centering-font-regexp)
-    (setq vertical-centering-font-regexp nil)
+    (set (make-local-variable 'vertical-centering-font-regexp) nil)
+    (set (make-local-variable 'face-font-rescale-alist) '(("dummy" . 1.0)))
     (unless (eq arg 'noimage)
       (goby-highlight-buffer 'image))
     (add-hook 'after-change-functions 'goby-highlight nil 'local)
@@ -220,6 +223,7 @@ Minor mode for editing large TrueType fonts and images.
     (goby-local-set-map))
    (t
     (kill-local-variable 'vertical-centering-font-regexp)
+    (kill-local-variable 'face-font-rescale-alist)
     (kill-local-variable 'after-change-functions)
     (kill-local-variable 'after-save-hook)
     (kill-local-variable 'tab-width)
@@ -503,7 +507,7 @@ Minor mode for editing large TrueType fonts and images.
 ;;;
 
 (defun goby-face-increase-ratio-region (beg end &optional rectangle)
-  "Enlarge the characters in the region. 
+  "Enlarge the characters in the region.
 If called with '\\[universal-argument]', the target is the rectangle."
   (interactive "r\nP")
   (goby-face-region
@@ -588,7 +592,7 @@ If called with '\\[universal-argument]', the target is the rectangle."
       (goby-face-region
        (match-beginning 0) (match-end 0) nil
        (lambda (frc)
-	 (goby-face-set-family frc goby-m-fonts-base)))))
+	 (goby-face-set-family frc goby-math-base)))))
   (goby-face-math-set-prop beg end t))
 
 (defun goby-face-math-set-raise (beg end factor)
@@ -615,7 +619,7 @@ If called with '\\[universal-argument]', the target is the rectangle."
 	 (setq raise 0.5)))
        (setq ratio (goby-face-math-magic ratio))
        (goby-face-set-ratio frc ratio)
-       (goby-face-set-family frc goby-m-fonts-base)
+       (goby-face-set-family frc goby-math-base)
        (goby-face-math-set-raise beg end raise))))) ;; tricky
 
 (defun goby-face-math-magic (num)
@@ -633,7 +637,7 @@ If called with '\\[universal-argument]', the target is the rectangle."
    beg end rectangle
    (lambda (frc)
      (goby-face-set-ratio frc (goby-face-math-magic (goby-face-get-ratio frc)))
-     (goby-face-set-family frc goby-m-fonts-base))))
+     (goby-face-set-family frc goby-math-base))))
 
 (defun goby-face-math-raise-region (beg end)
   "Raise the characters in the region."
@@ -698,6 +702,11 @@ If called with '\\[universal-argument]', the target is the rectangle."
 ;; see goby-image-regex
 (defun goby-image-get-file ()  (goby-match-string 1))
 (defun goby-image-get-scale () (goby-match-string 2))
+(defun goby-image-set-scale (scale)
+  (if (null scale) "" scale))
+(defun goby-image-get-tag ()
+  (let ((tag (goby-match-string 3)))
+    (if (null tag) goby-image-public tag)))
 
 (defun goby-image-type (file)
   (let (type)
@@ -749,7 +758,7 @@ If called with '\\[universal-argument]', the target is the rectangle."
     (setq pixel-width (/ (* (goby-display-pixel-width) numerator) denominator))
     (int-to-string pixel-width)))
 
-(defun goby-create-image (file &optional scale)
+(defun goby-create-image (file scale tag)
   (let ((type (goby-image-type file))
 	topnm pixel-width data image)
     (when (and (file-readable-p file)
@@ -772,23 +781,23 @@ If called with '\\[universal-argument]', the target is the rectangle."
       (if data
 	  (setq image (create-image data type 'data))
 	(setq image (create-image file type nil)))
-      (nconc image (list :mewfile file)))))
+      (nconc image (list :mewfile file :mewtag tag)))))
 
 (defun goby-visualize-image ()
   (goto-char (point-min))
   (let ((after-change-functions nil)
-	beg end file image scale)
+	beg end file image scale tag)
     (while (re-search-forward goby-image-regex nil t)
       (setq beg (match-beginning 0))
       (setq end (match-end 0))
       (setq file (goby-image-get-file))
       (setq scale (goby-image-get-scale))
-      (if (string= scale "") (setq scale nil))
+      (setq tag (goby-image-get-tag))
       ;; default-directory is not set when loading
       (unless (file-name-absolute-p file)
 	(setq file (expand-file-name
 		    file (file-name-directory (buffer-file-name)))))
-      (setq image (goby-create-image file scale))
+      (setq image (goby-create-image file scale tag))
       (goby-put-image beg end image))))
 
 (defun goby-insert-image (&optional scalep)
@@ -796,6 +805,7 @@ If called with '\\[universal-argument]', the target is the rectangle."
   (interactive "P")
   (let* ((after-change-functions nil)
 	 (scale (if scalep (read-string "Scale [% or A/B]: ")))
+	 (tag goby-image-public)
 	 (prompt (concat "[" (mapconcat 'symbol-name image-types "/") "] file: "))
 	 (file (read-file-name prompt))
 	 (efile (expand-file-name file))
@@ -806,10 +816,8 @@ If called with '\\[universal-argument]', the target is the rectangle."
     (message "Inserting the image...")
     (if (string-match regex efile)
 	(setq file (substring efile (length defdir))))
-    (setq image (goby-create-image efile scale))
-    (if scale
-	(insert (format goby-image-format2 file scale))
-      (insert (format goby-image-format file)))
+    (setq image (goby-create-image efile scale tag))
+    (insert (format goby-image-format file (goby-image-set-scale scale) tag))
     (goby-put-image beg (point) image)
     (if (/= (forward-line) 0) (insert "\n"))
     (goto-char beg)
@@ -818,22 +826,45 @@ If called with '\\[universal-argument]', the target is the rectangle."
 (defun goby-change-scale ()
   "Change the scale of the image."
   (interactive)
-  (let (scale beg end file image)
-    (if (not (looking-at goby-image-regex))
-	(message "No image here")
-      (setq file (goby-image-get-file))
-      (setq beg (match-beginning 0))
-      (setq end (match-end 0))
-      (setq scale (read-string "Scale [% or A/B]: "))
+  (if (not (looking-at goby-image-regex))
+      (message "No image here")
+    (let ((file (goby-image-get-file))
+	  (tag (goby-image-get-tag))
+	  (beg (match-beginning 0))
+	  (end (match-end 0))
+	  (scale (read-string "Scale [% or A/B]: "))
+	  image)
       (message "Scaling the image...")
       (delete-region beg end)
-      (setq image (goby-create-image file scale))
+      (setq image (goby-create-image file scale tag))
       (setq beg (point))
-      (insert (format goby-image-format2 file scale))
+      (insert (format goby-image-format file scale tag))
       (goby-put-image beg (point) image)
       (goto-char beg)
       (message "Scaling the image...done"))))
 
+(defun goby-toggle-tag ()
+  "Toggle the public/private tag of images"
+  (interactive)
+  (if (not (looking-at goby-image-regex))
+      (message "No image here")
+    (let ((file (goby-image-get-file))
+	  (scale (goby-image-get-scale))
+	  (oldtag (goby-image-get-tag))
+	  (beg (match-beginning 0))
+	  (end (match-end 0))
+	  newtag image)
+      (setq newtag (if (string= oldtag goby-image-public)
+		       goby-image-private goby-image-public))
+      (setq image (goby-get-extent beg))
+      (setcar (cdr (member :mewtag image)) newtag)
+      (delete-region beg end)
+      (setq beg (point))
+      (insert (format goby-image-format file (goby-image-set-scale scale) newtag))
+      (goby-put-image beg (point) image)
+      (goto-char beg)
+      (message "%s to %s" oldtag newtag))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
 ;;; Bar
